Label initialization time optimizations
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest6 patches 3 repliesIn review
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/6 | libnvdimm, dimm: Maximize label transfer sizedrivers/ | +6 | 0 replies | |
| 2/6 | nvdimm: Sanity check labeloffdrivers/ | +7 | 0 replies | |
| 3/6 | nvdimm: Clarify comment in sizeof_namespace_indexdrivers/ | +2 | 0 replies | |
| 4/6 | nvdimm: Remove empty if statementdrivers/ | +2 | 0 replies | |
| 5/6 | nvdimm: Split label init out from the logic for getting config datadrivers/ drivers/ drivers/ +2 more | +61 | 0 replies | |
| 6/6 | nvdimm: Use namespace index data to reduce number of label reads neededdrivers/ drivers/ drivers/ | +88 | 1 reply |
Reviews trailers per patch
None of the 6 patches has a Reviewed-by or Acked-by of their own; the series has one for all of them.
| Patch | Toshi Kani |
|---|---|
| Series | R-b |
| 1/6 | |
| 2/6 | |
| 3/6 | |
| 4/6 | |
| 5/6 | |
| 6/6 |
Trailers given in replies are filled; those carried in the patches from earlier versions are outlined with dashes.
Cover letter [nvdimm PATCH 0/6] Label initialization time optimizations
This patch set is intended to improve NVDIMM label read times by first increasing the upper limit on the label read/write size, and then reducing the number of reads by making use of the free label bitmap in the index to determine what labels are actually populated and only read those labels. In my testing on a system populated with 24 NVDIMM modules I see the total label init time drop from about 24 seconds down to 2 to 3 seconds.
In the process of coding this up I came across a few minor issues that I felt should be addressed so I have added a few patches for those fixes along the way.
---
Alexander Duyck (5):
nvdimm: Sanity check labeloff
nvdimm: Clarify comment in sizeof_namespace_index
nvdimm: Remove empty if statement
nvdimm: Split label init out from the logic for getting config data
nvdimm: Use namespace index data to reduce number of label reads needed
Dan Williams (1):
libnvdimm, dimm: Maximize label transfer size
drivers/nvdimm/dimm.c | 6 -- drivers/nvdimm/dimm_devs.c | 60 +++++++------------ drivers/nvdimm/label.c | 142 ++++++++++++++++++++++++++++++++++++++++++-- drivers/nvdimm/label.h | 4 - drivers/nvdimm/nd.h | 2 + 5 files changed, 163 insertions(+), 51 deletions(-)
--
_______________________________________________
Linux-nvdimm mailing list
[email protected]
https://lists.01.org/mailman/listinfo/linux-nvdimm